California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Choose an Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
HERE ARE YOUR RESULTS: Election Dates (Dates appear according to the Election Cycle above) 2011 - 2012 Election Dates: 1. SPECIAL ELECTION RUNOFF Tuesday, 1/4/11 2. SPECIAL ELECTION Tuesday, 2/15/11 3. SPECIAL ELECTION Tuesday, 2/15/11 4. SPECIAL ELECTION Tuesday, 3/8/11 5. SPECIAL ELECTION RUNOFF Tuesday, 4/19/11 6. SPECIAL ELECTION RUNOFF Tuesday, 5/3/11 7. PRIMARY ELECTION Tuesday, 6/5/12 8. GENERAL ELECTION Tuesday, 11/6/12 9. SPECIAL ELECTION Tuesday, 11/6/12
If you are searching for campaign finance information related to a specific office this is the place to begin. Included are officeholders for Governor, Lieutenant Governor, Secretary of State, Attorney General, State Controller, State Treasurer, Insurance Commissioner, State Superintendent of Public Instruction, Board of Equalization, State Senate, and State Assembly. Here you will find their names, campaign committees, and other information.
STATEWIDE OFFICES
GOVERNOR
BROWN, EDMUND G. (JERRY)
| LIEUTENANT GOVERNOR
NEWSOM, GAVIN
SECRETARY OF STATE
BOWEN, DEBRA
| CONTROLLER
CHIANG, JOHN
TREASURER
LOCKYER, BILL
| ATTORNEY GENERAL
HARRIS, KAMALA D.
SUPERINTENDENT OF PUBLIC INSTRUCTION
TORLAKSON, TOM
| INSURANCE COMMISSIONER
JONES, DAVE
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
YEE, BETTY T.
| MEMBER BOARD OF EQUALIZATION 02
RUNNER, GEORGE C.
MEMBER BOARD OF EQUALIZATION 03
STEEL, MICHELLE
| MEMBER BOARD OF EQUALIZATION 04
HORTON, JEROME E.
SENATE DISTRICTS
STATE SENATE 01
GAINES, EDWARD T
| STATE SENATE 02
EVANS, NOREEN M.
STATE SENATE 03
LENO, MARK
| STATE SENATE 04
LA MALFA, DOUG
STATE SENATE 05
WOLK, LOIS
| STATE SENATE 06
STEINBERG, DARRELL
STATE SENATE 07
DE SAULNIER, MARK
| STATE SENATE 08
YEE, LELAND Y.
STATE SENATE 09
HANCOCK, LONI
| STATE SENATE 10
CORBETT, ELLEN
STATE SENATE 11
SIMITIAN, S. JOSEPH
| STATE SENATE 12
CANNELLA, ANTHONY JOSEPH
STATE SENATE 13
ALQUIST, ELAINE
| STATE SENATE 14
BERRYHILL, TOM
STATE SENATE 15
BLAKESLEE, SAM
| STATE SENATE 16
RUBIO, MICHAEL J.
STATE SENATE 17
RUNNER, SHARON
| STATE SENATE 18
FULLER, JEAN
STATE SENATE 19
STRICKLAND, TONY
| STATE SENATE 20
PADILLA, ALEX
STATE SENATE 21
LIU, CAROL
| STATE SENATE 22
DE LEON, KEVIN
STATE SENATE 23
PAVLEY, FRAN
| STATE SENATE 24
HERNANDEZ, EDWARD P.
STATE SENATE 25
WRIGHT, RODERICK "ROD"
| STATE SENATE 26
PRICE, CURREN D.
STATE SENATE 27
LOWENTHAL, ALAN
| STATE SENATE 28
LIEU, TED
STATE SENATE 29
HUFF, ROBERT 'BOB'
| STATE SENATE 30
CALDERON, RONALD
STATE SENATE 31
DUTTON, BOB
| STATE SENATE 32
MC LEOD, GLORIA NEGRETE
STATE SENATE 33
WALTERS, MIMI
| STATE SENATE 34
CORREA, LOU
STATE SENATE 35
HARMAN, TOM
| STATE SENATE 36
ANDERSON, JOEL C.
STATE SENATE 37
EMMERSON, BILL
| STATE SENATE 38
WYLAND, MARK B.
STATE SENATE 39
KEHOE, CHRISTINE
| STATE SENATE 40
VARGAS, JUAN C.
ASSEMBLY DISTRICTS
ASSEMBLY 01
CHESBRO, WESLEY
| ASSEMBLY 02
NIELSEN, JIM
ASSEMBLY 03
LOGUE, DANIEL R.
| ASSEMBLY 04
GAINES, BETH B.
ASSEMBLY 05
PAN, RICHARD
| ASSEMBLY 06
HUFFMAN, JARED
ASSEMBLY 07
ALLEN, MICHAEL J.
| ASSEMBLY 08
YAMADA, MARIKO M.
ASSEMBLY 09
DICKINSON, ROGER
| ASSEMBLY 10
HUBER, ALYSON
ASSEMBLY 11
BONILLA, SUSAN
| ASSEMBLY 12
MA, FIONA
ASSEMBLY 13
AMMIANO, TOM
| ASSEMBLY 14
SKINNER, NANCY
ASSEMBLY 15
BUCHANAN, JOAN
| ASSEMBLY 16
SWANSON, SANDRE
ASSEMBLY 17
GALGIANI, CATHLEEN
| ASSEMBLY 18
HAYASHI, MARY
ASSEMBLY 19
HILL, JERRY A.
| ASSEMBLY 20
WIECKOWSKI, ROBERT
ASSEMBLY 21
GORDON, RICHARD S.
| ASSEMBLY 22
FONG, PAUL
ASSEMBLY 23
CAMPOS, NORA ELIA
| ASSEMBLY 24
BEALL, JIM
ASSEMBLY 25
OLSEN, KRISTIN M.
| ASSEMBLY 26
BERRYHILL, WILLIAM R.
ASSEMBLY 27
MONNING, WILLIAM W.
| ASSEMBLY 28
ALEJO, LUIS
ASSEMBLY 29
HALDERMAN, LINDA F.
| ASSEMBLY 30
VALADAO, DAVID G.
ASSEMBLY 31
PEREA, HENRY T.
| ASSEMBLY 32
GROVE, SHANNON
ASSEMBLY 33
ACHADJIAN, KHATCHIK
| ASSEMBLY 34
CONWAY, CONNIE
ASSEMBLY 35
WILLIAMS, DAS
| ASSEMBLY 36
KNIGHT, STEVE
ASSEMBLY 37
GORELL, JEFF
| ASSEMBLY 38
SMYTH, CAMERON
ASSEMBLY 39
FUENTES, FELIPE
| ASSEMBLY 40
BLUMENFIELD, BOB
ASSEMBLY 41
BROWNLEY, JULIA
| ASSEMBLY 42
FEUER, MICHAEL NELSON
ASSEMBLY 43
GATTO, MIKE
| ASSEMBLY 44
PORTANTINO, ANTHONY
ASSEMBLY 45
CEDILLO, GILBERT
| ASSEMBLY 46
PEREZ, JOHN A.
ASSEMBLY 47
MITCHELL, HOLLY J.
| ASSEMBLY 48
DAVIS, MIKE
ASSEMBLY 49
ENG, MICHAEL
| ASSEMBLY 50
LARA, RICARDO
ASSEMBLY 51
BRADFORD, STEVEN
| ASSEMBLY 52
HALL, ISADORE
ASSEMBLY 53
BUTLER, BETSY
| ASSEMBLY 54
LOWENTHAL, BONNIE
ASSEMBLY 55
FURUTANI, WARREN
| ASSEMBLY 56
MENDOZA, TONY
ASSEMBLY 57
HERNANDEZ, ROGER
| ASSEMBLY 58
CALDERON, CHARLES M.
ASSEMBLY 59
DONNELLY, TIM
| ASSEMBLY 60
HAGMAN, CURT
ASSEMBLY 61
TORRES, NORMA
| ASSEMBLY 62
CARTER, WILMER AMINA
ASSEMBLY 63
MORRELL, MIKE
| ASSEMBLY 64
NESTANDE, BRIAN
ASSEMBLY 65
COOK, PAUL J.
| ASSEMBLY 66
JEFFRIES, KEVIN D.
ASSEMBLY 67
SILVA, JAMES W.
| ASSEMBLY 68
MANSOOR, ALLAN R.
ASSEMBLY 69
SOLORIO, JOSE
| ASSEMBLY 70
WAGNER, DON
ASSEMBLY 71
MILLER, JEFF
| ASSEMBLY 72
NORBY, CHRIS
ASSEMBLY 73
HARKEY, DIANE
| ASSEMBLY 74
GARRICK, MARTIN W.
ASSEMBLY 75
FLETCHER, NATHAN B.
| ASSEMBLY 76
ATKINS, TONI G.
ASSEMBLY 77
JONES, BRIAN W.
| ASSEMBLY 78
BLOCK, MARTY J.
ASSEMBLY 79
HUESO, BEN
| ASSEMBLY 80
PEREZ, V. MANUEL